@@ -1,6 +1,6 @@
 package TestSetup;
 
-use Test::Mock::Cmd 'qr' => {
+use Test::Mock::Cmd 'qx' => {
     'git ls-remote --get-url' => sub { return 'git@github.com:abc/xzy.git' },
     'git symbolic-ref --short HEAD' => sub { return 'masterxx'; }
 };
